/*
 * Copyright 2009 Brian L. Browning
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package blbutil;

import java.util.Collection;
import java.util.Set;
import java.util.HashSet;

/**
 * Class ImmutableSet represents an immutable set.
 *
 * @param <E> the type of elements mained by the set.
 * 
 * @author Brian L Browning
 */
public class ImmutableSet<E> {

    private Set<E> set;

    /**
     * Constructs a new ImmutableSet instance equivalent to the specified
     * set.
     *
     * @param c a collection.
     * @throws NullPointerException if <code>c==null</code>.
     */
    public ImmutableSet(Collection<E> c) {
        if (c==null) {
            throw new NullPointerException("c==null");
        }
        this.set = new HashSet<E>(c);
    }

    /**
     * Returns <code>true</code> if the set represented by <code>this</code>
     * contains the specified element and <code>false</code> otherwise.
     * @param element an element
     * @return <code>true</code> if the set represented by <code>this</code>
     * contains the specified element and <code>false</code> otherwise.
     */
    public boolean contains(E element) {
        return set.contains(element);
    }

    @Override
    public int hashCode() {
        return set.hashCode();
    }

    @Override
    public boolean equals(Object o) {
        if (o==this) {
            return true;
        }
        if (!(o instanceof ImmutableSet)) {
            return false;
        }
        ImmutableSet otherSet = (ImmutableSet) o;
        return this.set.equals(otherSet.set);
    }

    /**
     * Returns a string representation of <code>this</code>.  The
     * exact details of the representation are unspecified and subject
     * to change.
     *
     * @return a string representation of <code>this</code>.
     */
    @Override
    public String toString() {
        return set.toString();
    }


}
